<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Travel Route Pro
 * @since Travel Route Pro 1.0.0
 * @return array An array of default values
 */

function travel_route_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$travel_route_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#29a0eb',
		'colorscheme'					=> 'default',
		
		// typography Options
		'theme_typography' 				=> '',
		'body_theme_typography' 		=> '',
		'theme_section_title_typography' 		=> '',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'wp_travel_sidebar_position'    => 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		'excerpt_text'           => esc_html__( 'Tour Details', 'travel-route-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html( 'Copyright &copy; %1$s %2$s by %3$s', 'travel-route-pro' ), '[the-year]', esc_html( $theme_data->get( 'Name') ), '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>' ),
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'Slider,Search,Package,About Us,CTA,Guide,Destination,Testimonial,Event,Counter',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'travel-route-pro' ),
		'hide_date' 					=> false,
		// 'hide_category'					=> false,
		// 'hide_author'					=> false,
		'archive_column'				=> 'col-2',

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Top bar
		'top_section_enable'			=> true,
		'top_contact_info'					=> __( 'Any Questions? Call Us: <a href="#">1-223-355-2214</a>', 'travel-route-pro' ),
		'search_section_enable'			=> true,

		// Banner
		'cta_section_enable'			=> true,
		'cta_content_type'			=> 'page',
		'cta_btn_label'				=> esc_html__( 'View All Details', 'travel-route-pro' ),

		// package
		'package_section_enable'		=> true,
		'package_content_type'			=> 'category',
		'package_count'					=> 3,
		'package_column'				=> 'col-3',
		'package_btn_txt'				=> esc_html__( 'See all packages', 'travel-route-pro' ),
		'package_btn_url'				=> '#',
		'package_title'					=> esc_html__( 'We are all here at your services for everything.', 'travel-route-pro' ),
		'package_sub_title'					=> esc_html__( 'Recommended Packages', 'travel-route-pro' ),

		// About
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'About Us', 'travel-route-pro' ),
		'about_description'				=> sprintf( '%1$s <br> %2$s',  esc_html__( 'There is evidence that perceptions of beauty are evolutionary determined, that things, aspects of people and landscapes considered beautiful are typically found in situations likely to give enhanced survival of the perceiving human genes.', 'travel-route-pro' ), esc_html__( 'They also include less tangible advantages such as a confidence (not always warranted) that the system will be forgiving of your and your children mistakes, that your bad habits will not be seen as racial flaws, that portrayals of your race in the media and in history books will be mostly positive.', 'travel-route-pro' ) ),
		'about_sub_title'				=> esc_html__( 'About Us', 'travel-route-pro' ),
		'tour_content_type'			=> 'cat',
		'tour_count'			=> 7,

		// Slider
		'slider_section_enable'			=> true,
		'slider_count'					=> 3,
		'slider_content_type'			=> 'category',

		// guide
		'guide_section_enable'			=> true,
		'guide_count'					=> 4,
		'guide_content_type'			=> 'category',
		'guide_title'					=> esc_html__( 'Survival Guide', 'travel-route-pro' ),
		'guide_subtitle'				=> esc_html__( 'Prepare Yourself', 'travel-route-pro' ),

		// destination
		'destination_section_enable'			=> true,
		'destination_count'					=> 6,
		'destination_content_type'			=> 'category',
		'destination_title'					=> esc_html__( 'Great Tour Around World', 'travel-route-pro' ),
		'destination_subtitle'				=> esc_html__( 'Find our most', 'travel-route-pro' ),
		'destination_btn'					=> esc_html__( 'Book Now', 'travel-route-pro' ),

		// destination
		'event_section_enable'			=> true,
		'event_count'					=> 6,
		'event_content_type'			=> 'category',
		'event_title'					=> esc_html__( 'Event Calendar', 'travel-route-pro' ),
		'event_subtitle'				=> esc_html__( 'Upcoming events', 'travel-route-pro' ),
		'event_btn'					=> esc_html__( 'View All Posts', 'travel-route-pro' ),
		'event_btn_url'					=> '#',

		// clients
		'client_section_enable'			=> true,
		'client_title'					=> esc_html__( 'We value our customer/clients above all others.', 'travel-route-pro' ),
		'client_content_type'			=> 'category',
		'client_count'					=> 6,

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_title'					=> esc_html__( 'Elite Travellers say', 'travel-route-pro' ),
		'testimonial_subtitle'				=> esc_html__( 'Find out what', 'travel-route-pro' ),
		'testimonial_content_type'		=> 'category',
		'testimonial_column'			=> 3,
		'testimonial_count'				=> 3,
		
		// Counter
		'counter_section_enable'		=> true,
		'counter_title'					=> esc_html__( 'Stats Counter', 'travel-route-pro' ),

		'counter_subtitle'				=> esc_html__( 'Statistics', 'travel-route-pro' ),
	);

	$output = apply_filters( 'travel_route_pro_default_theme_options', $travel_route_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}