<?php
/**
 * CTA Section options
 *
 * @package Theme Palace
 * @subpackage Travel Route Pro
 * @since Travel Route Pro 1.0.0
 */

// Add CTA section
$wp_customize->add_section( 'travel_route_pro_cta_section', array(
	'title'             => esc_html__( 'CTA','travel-route-pro' ),
	'description'       => esc_html__( 'CTA Section options.', 'travel-route-pro' ),
	'panel'             => 'travel_route_pro_front_page_panel',
) );

// CTA content enable control and setting
$wp_customize->add_setting( 'travel_route_pro_theme_options[cta_section_enable]', array(
	'default'			=> 	$options['cta_section_enable'],
	'sanitize_callback' => 'travel_route_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new travel_route_pro_Switch_Control( $wp_customize, 'travel_route_pro_theme_options[cta_section_enable]', array(
	'label'             => esc_html__( 'CTA Section Enable', 'travel-route-pro' ),
	'section'           => 'travel_route_pro_cta_section',
	'on_off_label' 		=> travel_route_pro_switch_options(),
) ) );

// CTA content type control and setting
$wp_customize->add_setting( 'travel_route_pro_theme_options[cta_content_type]', array(
	'default'          	=> $options['cta_content_type'],
	'sanitize_callback' => 'travel_route_pro_sanitize_select',
) );

$choices = array( 
		'page' 		=> esc_html__( 'Page', 'travel-route-pro' ),
		'post' 		=> esc_html__( 'Post', 'travel-route-pro' ),
	);
if ( class_exists( 'WP_Travel' ) ) {
	$choices['trip'] = esc_html__( 'Trip', 'travel-route-pro' );
}

$wp_customize->add_control( 'travel_route_pro_theme_options[cta_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-route-pro' ),
	'section'           => 'travel_route_pro_cta_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_route_pro_is_cta_section_enable',
	'choices'			=> $choices,
) );

// cta pages drop down chooser control and setting
$wp_customize->add_setting( 'travel_route_pro_theme_options[cta_content_page]', array(
	'sanitize_callback' => 'travel_route_pro_sanitize_page',
) );

$wp_customize->add_control( new travel_route_pro_Dropdown_Chooser( $wp_customize, 'travel_route_pro_theme_options[cta_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'travel-route-pro' ),
	'section'           => 'travel_route_pro_cta_section',
	'choices'			=> travel_route_pro_page_choices(),
	'active_callback'	=> 'travel_route_pro_is_cta_section_content_page_enable',
) ) );

// cta posts drop down chooser control and setting
$wp_customize->add_setting( 'travel_route_pro_theme_options[cta_content_post]', array(
	'sanitize_callback' => 'travel_route_pro_sanitize_page',
) );

$wp_customize->add_control( new travel_route_pro_Dropdown_Chooser( $wp_customize, 'travel_route_pro_theme_options[cta_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'travel-route-pro' ),
	'section'           => 'travel_route_pro_cta_section',
	'choices'			=> travel_route_pro_post_choices(),
	'active_callback'	=> 'travel_route_pro_is_cta_section_content_post_enable',
) ) );

if ( class_exists( 'WP_Travel' ) ) {
	// slider trip drop down chooser control and setting
	$wp_customize->add_setting( 'travel_route_pro_theme_options[cta_content_trip]', array(
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( new travel_route_pro_Dropdown_Chooser( $wp_customize, 'travel_route_pro_theme_options[cta_content_trip]', array(
		'label'             => esc_html__( 'Select Trip', 'travel-route-pro' ),
		'section'           => 'travel_route_pro_cta_section',
		'choices'			=> travel_route_pro_trip_choices(),
		'active_callback'	=> 'travel_route_pro_is_cta_section_content_trip_enable',
	) ) );
}

// CTA btn label setting and control
$wp_customize->add_setting( 'travel_route_pro_theme_options[cta_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_route_pro_theme_options[cta_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'travel-route-pro' ),
	'section'        	=> 'travel_route_pro_cta_section',
	'active_callback' 	=> 'travel_route_pro_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_route_pro_theme_options[cta_btn_label]', array(
		'selector'            => '#call-to-action .view-all .btn',
		'settings'            => 'travel_route_pro_theme_options[cta_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_route_pro_cta_btn_label_partial',
    ) );
}

