<?php
/**
 * Guide Section options
 *
 * @package Theme Palace
 * @subpackage Travel Route Pro
 * @since Travel Route Pro 1.0.0
 */

// Add Guide section
$wp_customize->add_section( 'travel_route_pro_guide_section', array(
	'title'             => esc_html__( 'Guide','travel-route-pro' ),
	'description'       => esc_html__( 'Guide Section options.', 'travel-route-pro' ),
	'panel'             => 'travel_route_pro_front_page_panel',
) );

// Guide content enable control and setting
$wp_customize->add_setting( 'travel_route_pro_theme_options[guide_section_enable]', array(
	'default'			=> 	$options['guide_section_enable'],
	'sanitize_callback' => 'travel_route_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new travel_route_pro_Switch_Control( $wp_customize, 'travel_route_pro_theme_options[guide_section_enable]', array(
	'label'             => esc_html__( 'Guide Section Enable', 'travel-route-pro' ),
	'section'           => 'travel_route_pro_guide_section',
	'on_off_label' 		=> travel_route_pro_switch_options(),
) ) );

// guide title setting and control
$wp_customize->add_setting( 'travel_route_pro_theme_options[guide_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['guide_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_route_pro_theme_options[guide_title]', array(
	'label'           	=> esc_html__( 'Title', 'travel-route-pro' ),
	'section'        	=> 'travel_route_pro_guide_section',
	'active_callback' 	=> 'travel_route_pro_is_guide_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_route_pro_theme_options[guide_title]', array(
		'selector'            => '#travel-preparation .section-header h2.section-title',
		'settings'            => 'travel_route_pro_theme_options[guide_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_route_pro_guide_title_partial',
    ) );
}

// guide description setting and control
$wp_customize->add_setting( 'travel_route_pro_theme_options[guide_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['guide_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_route_pro_theme_options[guide_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'travel-route-pro' ),
	'section'        	=> 'travel_route_pro_guide_section',
	'active_callback' 	=> 'travel_route_pro_is_guide_section_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_route_pro_theme_options[guide_subtitle]', array(
		'selector'            => '#travel-preparation .section-header span.section-subtitle',
		'settings'            => 'travel_route_pro_theme_options[guide_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_route_pro_guide_subtitle_partial',
    ) );
}

// guide image setting and control.
$wp_customize->add_setting( 'travel_route_pro_theme_options[guide_image]', array(
	'sanitize_callback' => 'travel_route_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travel_route_pro_theme_options[guide_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'travel-route-pro' ),
		'section'     		=> 'travel_route_pro_guide_section',
		'active_callback'	=> 'travel_route_pro_is_guide_section_enable',
) ) );

// guide number control and setting
$wp_customize->add_setting( 'travel_route_pro_theme_options[guide_count]', array(
	'default'          	=> $options['guide_count'],
	'sanitize_callback' => 'travel_route_pro_sanitize_number_range',
	'validate_callback' => 'travel_route_pro_validate_guide_count',
) );

$wp_customize->add_control( 'travel_route_pro_theme_options[guide_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travel-route-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 4. Please input the valid number and save. Then refresh the page to see the change.', 'travel-route-pro' ),
	'section'           => 'travel_route_pro_guide_section',
	'active_callback'   => 'travel_route_pro_is_guide_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 4,
		'style' => 'width: 100px;'
		),
) );

// Guide content type control and setting
$wp_customize->add_setting( 'travel_route_pro_theme_options[guide_content_type]', array(
	'default'          	=> $options['guide_content_type'],
	'sanitize_callback' => 'travel_route_pro_sanitize_select',
) );

$choices = array( 
		'page' 		=> esc_html__( 'Page', 'travel-route-pro' ),
		'post' 		=> esc_html__( 'Post', 'travel-route-pro' ),
		'category' 	=> esc_html__( 'Category', 'travel-route-pro' ),
	);
if ( class_exists( 'WP_Travel' ) ) {
	$choices['trip'] = esc_html__( 'Trip', 'travel-route-pro' );
}
$wp_customize->add_control( 'travel_route_pro_theme_options[guide_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-route-pro' ),
	'section'           => 'travel_route_pro_guide_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_route_pro_is_guide_section_enable',
	'choices'			=> $choices,
) );

for ( $i = 1; $i <= $options['guide_count']; $i++ ) :
	// guide pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_route_pro_theme_options[guide_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_route_pro_sanitize_page',
	) );

	$wp_customize->add_control( new travel_route_pro_Dropdown_Chooser( $wp_customize, 'travel_route_pro_theme_options[guide_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-route-pro' ), $i ),
		'section'           => 'travel_route_pro_guide_section',
		'choices'			=> travel_route_pro_page_choices(),
		'active_callback'	=> 'travel_route_pro_is_guide_section_content_page_enable',
	) ) );

	// guide posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_route_pro_theme_options[guide_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_route_pro_sanitize_page',
	) );

	$wp_customize->add_control( new travel_route_pro_Dropdown_Chooser( $wp_customize, 'travel_route_pro_theme_options[guide_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travel-route-pro' ), $i ),
		'section'           => 'travel_route_pro_guide_section',
		'choices'			=> travel_route_pro_post_choices(),
		'active_callback'	=> 'travel_route_pro_is_guide_section_content_post_enable',
	) ) );

	if ( class_exists( 'WP_Travel' ) ) {
		// slider trip drop down chooser control and setting
		$wp_customize->add_setting( 'travel_route_pro_theme_options[guide_content_trip_' . $i . ']', array(
			'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( new travel_route_pro_Dropdown_Chooser( $wp_customize, 'travel_route_pro_theme_options[guide_content_trip_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Trip %d', 'travel-route-pro' ), $i ),
			'section'           => 'travel_route_pro_guide_section',
			'choices'			=> travel_route_pro_trip_choices(),
			'active_callback'	=> 'travel_route_pro_is_guide_section_content_trip_enable',
		) ) );
	}

	// guide icon setting and control
	$wp_customize->add_setting( 'travel_route_pro_theme_options[guide_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new travel_route_pro_Icon_Picker( $wp_customize, 'travel_route_pro_theme_options[guide_icon_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Icon %d', 'travel-route-pro' ), $i ),
		'section'        	=> 'travel_route_pro_guide_section',
		'active_callback' 	=> 'travel_route_pro_is_guide_section_enable',
	) ) );

	// guide hr setting and control
	$wp_customize->add_setting( 'travel_route_pro_theme_options[guide_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new travel_route_pro_Customize_Horizontal_Line( $wp_customize, 'travel_route_pro_theme_options[guide_hr_'. $i .']',
		array(
			'section'         => 'travel_route_pro_guide_section',
			'active_callback' => 'travel_route_pro_is_guide_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_route_pro_theme_options[guide_content_category]', array(
	'sanitize_callback' => 'travel_route_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new travel_route_pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_route_pro_theme_options[guide_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-route-pro' ),
	'description'      	=> esc_html__( 'Note: Guide selected no of posts will be shown from selected category', 'travel-route-pro' ),
	'section'           => 'travel_route_pro_guide_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_route_pro_is_guide_section_content_category_enable'
) ) );