<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Travel Route Pro
 * @since Travel Route Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'travel_route_pro_slider_section', array(
	'title'             => esc_html__( 'Slider','travel-route-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'travel-route-pro' ),
	'panel'             => 'travel_route_pro_front_page_panel',
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'travel_route_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'travel_route_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new travel_route_pro_Switch_Control( $wp_customize, 'travel_route_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'travel-route-pro' ),
	'section'           => 'travel_route_pro_slider_section',
	'on_off_label' 		=> travel_route_pro_switch_options(),
) ) );

// slider number control and setting
$wp_customize->add_setting( 'travel_route_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'travel_route_pro_sanitize_number_range',
	'validate_callback' => 'travel_route_pro_validate_slider_count',
) );

$wp_customize->add_control( 'travel_route_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travel-route-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'travel-route-pro' ),
	'section'           => 'travel_route_pro_slider_section',
	'active_callback'   => 'travel_route_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Slider content type control and setting
$wp_customize->add_setting( 'travel_route_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'travel_route_pro_sanitize_select',
) );

$choices = array( 
		'page' 		=> esc_html__( 'Page', 'travel-route-pro' ),
		'post' 		=> esc_html__( 'Post', 'travel-route-pro' ),
		'category' 	=> esc_html__( 'Category', 'travel-route-pro' ),
	);
if ( class_exists( 'WP_Travel' ) ) {
	$choices['trip'] = esc_html__( 'Trip', 'travel-route-pro' );
}
$wp_customize->add_control( 'travel_route_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-route-pro' ),
	'section'           => 'travel_route_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_route_pro_is_slider_section_enable',
	'choices'			=> $choices,
) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :
	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_route_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_route_pro_sanitize_page',
	) );

	$wp_customize->add_control( new travel_route_pro_Dropdown_Chooser( $wp_customize, 'travel_route_pro_theme_options[slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-route-pro' ), $i ),
		'section'           => 'travel_route_pro_slider_section',
		'choices'			=> travel_route_pro_page_choices(),
		'active_callback'	=> 'travel_route_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_route_pro_theme_options[slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_route_pro_sanitize_page',
	) );

	$wp_customize->add_control( new travel_route_pro_Dropdown_Chooser( $wp_customize, 'travel_route_pro_theme_options[slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travel-route-pro' ), $i ),
		'section'           => 'travel_route_pro_slider_section',
		'choices'			=> travel_route_pro_post_choices(),
		'active_callback'	=> 'travel_route_pro_is_slider_section_content_post_enable',
	) ) );

	if ( class_exists( 'WP_Travel' ) ) {
		// slider trip drop down chooser control and setting
		$wp_customize->add_setting( 'travel_route_pro_theme_options[slider_content_trip_' . $i . ']', array(
			'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( new travel_route_pro_Dropdown_Chooser( $wp_customize, 'travel_route_pro_theme_options[slider_content_trip_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Trip %d', 'travel-route-pro' ), $i ),
			'section'           => 'travel_route_pro_slider_section',
			'choices'			=> travel_route_pro_trip_choices(),
			'active_callback'	=> 'travel_route_pro_is_slider_section_content_trip_enable',
		) ) );
	}

	// slider title setting and control
	$wp_customize->add_setting( 'travel_route_pro_theme_options[slider_sub_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'travel_route_pro_theme_options[slider_sub_title_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Sub title %d', 'travel-route-pro' ), $i ),
		'section'        	=> 'travel_route_pro_slider_section',
		'active_callback' 	=> 'travel_route_pro_is_slider_section_enable',
		'type'				=> 'text',
	) );

	// slider read more setting and control
	$wp_customize->add_setting( 'travel_route_pro_theme_options[slider_read_more_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'travel_route_pro_theme_options[slider_read_more_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Read more %d', 'travel-route-pro' ), $i ),
		'section'        	=> 'travel_route_pro_slider_section',
		'active_callback' 	=> 'travel_route_pro_is_slider_section_enable',
		'type'				=> 'text',
	) );

	// slider hr setting and control
	$wp_customize->add_setting( 'travel_route_pro_theme_options[slider_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new travel_route_pro_Customize_Horizontal_Line( $wp_customize, 'travel_route_pro_theme_options[slider_hr_'. $i .']',
		array(
			'section'         => 'travel_route_pro_slider_section',
			'active_callback' => 'travel_route_pro_is_slider_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_route_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'travel_route_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new travel_route_pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_route_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-route-pro' ),
	'description'      	=> esc_html__( 'Note: Slider selected no of posts will be shown from selected category', 'travel-route-pro' ),
	'section'           => 'travel_route_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_route_pro_is_slider_section_content_category_enable'
) ) );
