<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Travel Route Pro
 * @since Travel Route Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function travel_route_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'travel-route-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function travel_route_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'travel-route-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of iteneries for post choices.
 * @return Array Array of post ids and name.
 */
function travel_route_pro_trip_choices() {
    if ( ! class_exists( 'WP_Travel' ) ) {
        return;
    }
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'travel-route-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'travel_route_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function travel_route_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'travel-route-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'travel-route-pro' ),
            'header-font-2'   => esc_html__( 'Cherry Swash', 'travel-route-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'travel-route-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'travel-route-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'travel-route-pro' ),
        );

        $output = apply_filters( 'travel_route_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'travel_route_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function travel_route_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'travel-route-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'travel-route-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'travel-route-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'travel-route-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'travel-route-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'travel-route-pro' ),
        );

        $output = apply_filters( 'travel_route_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'travel_route_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function travel_route_pro_site_layout() {
        $travel_route_pro_site_layout = array(
            'wide-layout'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'travel_route_pro_site_layout', $travel_route_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'travel_route_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function travel_route_pro_selected_sidebar() {
        $travel_route_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'travel-route-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'travel-route-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'travel-route-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'travel-route-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'travel-route-pro' ),
        );

        $output = apply_filters( 'travel_route_pro_selected_sidebar', $travel_route_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'travel_route_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function travel_route_pro_global_sidebar_position() {
        $travel_route_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'travel_route_pro_global_sidebar_position', $travel_route_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'travel_route_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function travel_route_pro_sidebar_position() {
        $travel_route_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'travel_route_pro_sidebar_position', $travel_route_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'travel_route_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function travel_route_pro_pagination_options() {
        $travel_route_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'travel-route-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'travel-route-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'travel-route-pro' ),
        );

        $output = apply_filters( 'travel_route_pro_pagination_options', $travel_route_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'travel_route_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function travel_route_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'travel-route-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'travel-route-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'travel-route-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'travel-route-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'travel-route-pro' ),
            'spinner-circle'        => esc_html__( 'Circle', 'travel-route-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'travel-route-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'travel-route-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'travel-route-pro' ),
        );
        return apply_filters( 'travel_route_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'travel_route_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function travel_route_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'travel-route-pro' ),
            'off'       => esc_html__( 'Disable', 'travel-route-pro' )
        );
        return apply_filters( 'travel_route_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'travel_route_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function travel_route_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'travel-route-pro' ),
            'off'       => esc_html__( 'No', 'travel-route-pro' )
        );
        return apply_filters( 'travel_route_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'travel_route_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function travel_route_pro_sortable_sections() {
        $sections = array(
            'slider'    => esc_html__( 'Slider', 'travel-route-pro' ),
            'search'    => esc_html__( 'Search', 'travel-route-pro' ),
            'package'   => esc_html__( 'Package', 'travel-route-pro' ),
            'about'     => esc_html__( 'About Us', 'travel-route-pro' ),
            'cta'    => esc_html__( 'CTA', 'travel-route-pro' ),
            'guide'     => esc_html__( 'Guide', 'travel-route-pro' ),
            'destination'     => esc_html__( 'Destination', 'travel-route-pro' ),
            'testimonial' => esc_html__( 'Testimonial', 'travel-route-pro' ),
            'event' => esc_html__( 'Event', 'travel-route-pro' ),
            'counter'   => esc_html__( 'Counter', 'travel-route-pro' ),
        );
        return apply_filters( 'travel_route_pro_sortable_sections', $sections );
    }
endif;

/**
 * Get an array of google fonts.
 * 
 */
function travel_route_pro_font_choices() {
    $font_family_arr = array();
    $font_family_arr[''] = esc_html__( '--Default--', 'travel-route-pro' );

    // Make the request
    $request = wp_remote_get( get_theme_file_uri( 'assets/uploads/webfonts.json' ) );

    if( is_wp_error( $request ) ) {
        return false; // Bail early
    }
    // Retrieve the data
    $body = wp_remote_retrieve_body( $request );
    $data = json_decode( $body );
    if ( ! empty( $data ) ) {
        foreach ( $data->items as $items => $fonts ) {
            $family_str_arr = explode( ' ', $fonts->family );
            $family_value = implode( '-', array_map( 'strtolower', $family_str_arr ) );
            $font_family_arr[ $family_value ] = $fonts->family;
        }
    }

    return apply_filters( 'travel_route_pro_font_choices', $font_family_arr );
}