<?php
/**
 * Counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage Travel Route Pro
 * @since Travel Route Pro 1.0.0
 */
if ( ! function_exists( 'travel_route_pro_add_counter_section' ) ) :
    /**
    * Add counter section
    *
    *@since Travel Route Pro 1.0.0
    */
    function travel_route_pro_add_counter_section() {
    	$options = travel_route_pro_get_theme_options();
        // Check if counter is enabled on frontpage
        $counter_enable = apply_filters( 'travel_route_pro_section_status', true, 'counter_section_enable' );

        if ( true !== $counter_enable ) {
            return false;
        }

        // Render counter section now.
        travel_route_pro_render_counter_section();
    }
endif;

if ( ! function_exists( 'travel_route_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since Travel Route Pro 1.0.0
   *
   */
   function travel_route_pro_render_counter_section() {
        $options = travel_route_pro_get_theme_options();
        $image = ! empty( $options['counter_image'] ) ? $options['counter_image'] : '';
        
        $col = 0;
        for ( $i = 1; $i <= 4 ; $i++) { 
            if ( ! empty( $options['counter_value_' . $i] ) && ! empty( $options['counter_label_' . $i] ) ) : 
                $col++;
            endif; 
        } 

        if ( 0 === $col ) {
            return;
        }
        ?>

        <div id="counter-section" class="relative page-section" style="background-image: url('<?php echo esc_url( $image ); ?>');">
            <!-- supports col-1, col-2, col-3, col-4 -->
            <div class="overlay"></div>
            <div class="wrapper">
                <div class="section-header">
                    <?php if ( ! empty( $options['counter_title'] ) ) : ?>
                        <span class="section-subtitle"><?php echo esc_html( $options['counter_title'] ); ?></span>
                    <?php endif; ?>
                    <?php if ( ! empty( $options['counter_subtitle'] ) ) : ?>
                        <h2 class="section-title"><?php echo esc_html( $options['counter_subtitle'] ); ?></h2>
                    <?php endif; ?>
                </div><!-- .section-header -->
                <div class="section-content clear col-4">
                    <?php for ( $i = 1; $i <= 4 ; $i++) { 
                        if ( ! empty( $options['counter_value_' . $i] ) && ! empty( $options['counter_label_' . $i] ) ) : ?>
                            <article>
                                <i class="fa <?php echo esc_attr( $options['counter_icon_' . $i] ); ?>"></i>
                                <h4><?php echo esc_html( $options['counter_value_' . $i] ); ?></h4>
                                <p><?php echo esc_html( $options['counter_label_' . $i] ); ?></p>
                            </article>
                        <?php endif; 
                    } ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #counter -->

    <?php }
endif;