<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Travel Route Pro
 * @since Travel Route Pro 1.0.0
 */

$options = travel_route_pro_get_theme_options();


if ( ! function_exists( 'travel_route_pro_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Travel Route Pro 1.0.0
	 */
	function travel_route_pro_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'travel_route_pro_doctype', 'travel_route_pro_doctype', 10 );


if ( ! function_exists( 'travel_route_pro_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Travel Route Pro 1.0.0
	 *
	 */
	function travel_route_pro_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'travel_route_pro_before_wp_head', 'travel_route_pro_head', 10 );

if ( ! function_exists( 'travel_route_pro_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Travel Route Pro 1.0.0
	 *
	 */
	function travel_route_pro_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'travel-route-pro' ); ?></a>

		<?php
	}
endif;
add_action( 'travel_route_pro_page_start_action', 'travel_route_pro_page_start', 10 );

if ( ! function_exists( 'travel_route_pro_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Travel Route Pro 1.0.0
	 *
	 */
	function travel_route_pro_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'travel_route_pro_page_end_action', 'travel_route_pro_page_end', 10 );

if ( ! function_exists( 'travel_route_pro_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Travel Route Pro 1.0.0
	 *
	 */
	function travel_route_pro_header_start() {
		?>
		<header id="masthead" class="site-header" role="banner">
		<?php
	}
endif;
add_action( 'travel_route_pro_header_action', 'travel_route_pro_header_start', 10 );

if ( ! function_exists( 'travel_route_pro_top_header' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Travel Route Pro 1.0.0
	 *
	 */
	function travel_route_pro_top_header() {

		$options = travel_route_pro_get_theme_options();
		if ( ! $options['top_section_enable'] ) {
			return;
		}
		?>
		<div id="top-bar" class="relative">
			<?php
			echo travel_route_pro_get_svg( array( 'icon' => 'up' ) );
			echo travel_route_pro_get_svg( array( 'icon' => 'down' ) );
			?>

			<div class="wrapper">
				<div class="col-2 clear">
				    <?php if ( ! empty( $options['top_contact_info'] ) ) { ?>
					    <div class="hentry">
					        <ul class="contact-info">
					            <li>
									<?php 
									echo travel_route_pro_get_svg( array( 'icon' => 'phone' ) );
					                echo wp_kses_post( $options['top_contact_info'] );
					                ?>
					            </li>
					        </ul><!-- .contact-info -->
					    </div><!-- .hentry -->
				    <?php } ?>

				    <?php if ( has_nav_menu( 'top' ) ) { ?>
					    <div class="hentry">
					    	<?php
					    	$defaults = array(
					    		'theme_location' => 'top',
					    		'container' => 'div',
					    		'container_class' => 'secondary-menu',
					    		'menu_class' => 'menu',
					    		'echo' => true,
					    		'fallback_cb' => 'travel_route_pro_menu_fallback_cb',
					    	);
					    	
					    	wp_nav_menu( $defaults );
					    	?>
					    </div><!-- .hentry -->
					<?php } ?>
				</div><!-- .col-2 -->
		    </div><!-- .wrapper -->
		</div><!-- #top-bar -->
		<?php
	}
endif;
add_action( 'travel_route_pro_header_action', 'travel_route_pro_top_header', 10 );

if ( ! function_exists( 'travel_route_pro_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Travel Route Pro 1.0.0
	 *
	 */
	function travel_route_pro_site_branding() {
		$options  = travel_route_pro_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>
        <div class="wrapper main-menu">
			<div class="site-branding">
				<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
					<div class="site-logo">
						<?php the_custom_logo(); ?>
					</div>
				<?php } 
				if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
					<div id="site-identity">
						<?php
						if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
							if ( travel_route_pro_is_latest_posts() ) : ?>
								<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
							<?php else : ?>
								<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
							<?php
							endif;
						} 
						if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
							$description = get_bloginfo( 'description', 'display' );
							if ( $description || is_customize_preview() ) : ?>
								<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
							<?php
							endif; 
						}?>
					</div>
				<?php endif; ?>
			</div><!-- .site-branding -->
		<?php
	}
endif;
add_action( 'travel_route_pro_header_action', 'travel_route_pro_site_branding', 30 );

if ( ! function_exists( 'travel_route_pro_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Travel Route Pro 1.0.0
	 *
	 */
	function travel_route_pro_site_navigation() {
		$options = travel_route_pro_get_theme_options();
		?>
			<nav id="site-navigation" class="main-navigation" role="navigation">
				<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
					<span class="menu-label"><?php esc_html_e( 'Menu', 'travel-route-pro' ); ?></span>
					<?php
					echo travel_route_pro_get_svg( array( 'icon' => 'menu' ) );
					echo travel_route_pro_get_svg( array( 'icon' => 'close' ) );
					?>					
				</button>

				<?php  
        		$defaults = array(
        			'theme_location' => 'primary',
        			'container' => false,
        			'menu_class' => 'menu nav-menu',
        			'menu_id' => 'primary-menu',
        			'echo' => true,
        			'fallback_cb' => 'travel_route_pro_menu_fallback_cb',
        			'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s</ul>',
        		);
        	
        		wp_nav_menu( $defaults );
	        	?>
			</nav><!-- #site-navigation -->
        </div><!-- .wrapper -->
		<?php
	}
endif;
add_action( 'travel_route_pro_header_action', 'travel_route_pro_site_navigation', 40 );


if ( ! function_exists( 'travel_route_pro_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Travel Route Pro 1.0.0
	 *
	 */
	function travel_route_pro_header_end() {
		?>
		</header><!-- #masthead -->
		<?php
	}
endif;

add_action( 'travel_route_pro_header_action', 'travel_route_pro_header_end', 50 );

if ( ! function_exists( 'travel_route_pro_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Travel Route Pro 1.0.0
	 *
	 */
	function travel_route_pro_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'travel_route_pro_content_start_action', 'travel_route_pro_content_start', 10 );

if ( ! function_exists( 'travel_route_pro_header_image' ) ) :
	/**
	 * Header Image codes
	 *
	 * @since Travel Route Pro 1.0.0
	 *
	 */
	function travel_route_pro_header_image() {
		if ( travel_route_pro_is_frontpage() )
			return;
		$header_image = get_header_image();
		$class = '';
		if ( is_singular() ) :
			$class = ( has_post_thumbnail() || ! empty( $header_image ) ) ? '' : 'header-media-disabled';
		else :
			$class = ! empty( $header_image ) ? '' : 'header-media-disabled';
		endif;
		
		if ( is_singular() && has_post_thumbnail() ) : 
			$header_image = get_the_post_thumbnail_url( get_the_id(), 'full' );
    	endif; ?>

    	<div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <header class="page-header">
                    <?php echo travel_route_pro_custom_header_banner_title(); ?>
                </header>
                <?php  travel_route_pro_add_breadcrumb(); ?>
            </div><!-- .wrapper -->
        </div><!-- #page-site-header -->
	<?php
	}
endif;
add_action( 'travel_route_pro_header_image_action', 'travel_route_pro_header_image', 10 );

if ( ! function_exists( 'travel_route_pro_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since Travel Route Pro 1.0.0
	 */
	function travel_route_pro_add_breadcrumb() {
		$options = travel_route_pro_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( travel_route_pro_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * travel_route_pro_simple_breadcrumb hook
				 *
				 * @hooked travel_route_pro_simple_breadcrumb -  10
				 *
				 */
				do_action( 'travel_route_pro_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
		return;
	}
endif;

if ( ! function_exists( 'travel_route_pro_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Travel Route Pro 1.0.0
	 *
	 */
	function travel_route_pro_content_end() {
		?>
			<div class="menu-overlay"></div>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'travel_route_pro_content_end_action', 'travel_route_pro_content_end', 10 );

if ( ! function_exists( 'travel_route_pro_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Travel Route Pro 1.0.0
	 *
	 */
	function travel_route_pro_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
		<?php
	}
endif;
add_action( 'travel_route_pro_footer', 'travel_route_pro_footer_start', 10 );

if ( ! function_exists( 'travel_route_pro_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Travel Route Pro 1.0.0
	 *
	 */
	function travel_route_pro_footer_site_info() {
		$options = travel_route_pro_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text = $options['copyright_text']; 

		if ( ! empty( $copyright_text ) && has_nav_menu( 'social' ) ) {
			$col = 2;
		} else {
			$col = 1;
		}
		?>
			<div class="site-info col-<?php echo esc_attr( $col ); ?>">
                <div class="wrapper">
                    <span>
                    	<?php 
                    	echo travel_route_pro_santize_allow_tag( $copyright_text ); 
                    	if ( function_exists( 'the_privacy_policy_link' ) ) {
							the_privacy_policy_link( ' | ' );
						}
                    	?>
                	</span>

                	<?php if ( has_nav_menu( 'social' ) ) { ?>
	                    <span>
	                    	<?php
	                    	$defaults = array(
	                    		'theme_location' => 'social',
	                    		'container' => false,
	                    		'menu_class' => 'social-icons',
	                    		'menu_id' => '',
	                    		'echo' => true,
	                    		'link_before' => '<span class="screen-reader-text">',
	                    		'link_after' => '</span>',
	                    	);
	                    	
	                    	wp_nav_menu( $defaults );
	                    	?>
	                    </span>
                	<?php } ?>
                </div><!-- .wrapper -->    
            </div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'travel_route_pro_footer', 'travel_route_pro_footer_site_info', 40 );

if ( ! function_exists( 'travel_route_pro_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Travel Route Pro 1.0.0
	 *
	 */
	function travel_route_pro_footer_scroll_to_top() {
		$options  = travel_route_pro_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo travel_route_pro_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'travel_route_pro_footer', 'travel_route_pro_footer_scroll_to_top', 40 );

if ( ! function_exists( 'travel_route_pro_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Travel Route Pro 1.0.0
	 *
	 */
	function travel_route_pro_footer_end() {
		?>
		</footer>
		<div class="popup-overlay"></div>
		<?php
	}
endif;
add_action( 'travel_route_pro_footer', 'travel_route_pro_footer_end', 100 );

if ( ! function_exists( 'travel_route_pro_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Travel Route Pro 1.0.0
	 *
	 */
	function travel_route_pro_loader() {
		$options = travel_route_pro_get_theme_options();
		if ( $options['loader_enable'] ) { ?>
			<div id="loader">
	            <div class="loader-container">
	            	<?php if ( 'default' == $options['loader_icon'] ) : ?>
		                <div id="preloader">
		                    <span></span>
		                    <span></span>
		                    <span></span>
		                    <span></span>
		                    <span></span>
		                </div>
		            <?php else :
		            	echo travel_route_pro_get_svg( array( 'icon' => esc_attr( $options['loader_icon'] ) ) );
		            endif; ?>
	            </div>
	        </div><!-- #loader -->
	        <div class="menu-overlay"></div>
		<?php }
	}
endif;
add_action( 'travel_route_pro_before_header', 'travel_route_pro_loader', 10 );

if ( ! function_exists( 'travel_route_pro_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since Travel Route Pro 1.0.0
	 *
	 */
	function travel_route_pro_infinite_loader_spinner() { 
		global $post;
		$options = travel_route_pro_get_theme_options();
		if ( $options['pagination_type'] == 'infinite' ) :
			if ( count( $post ) > 0 ) {
				echo '<div class="blog-loader">' . travel_route_pro_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';
			}
		endif;
	}
endif;
add_action( 'travel_route_pro_infinite_loader_spinner_action', 'travel_route_pro_infinite_loader_spinner', 10 );
